==> qcad-3.32.4.0-1-x86_64.pkg.tar.zst: usr/lib/qcad/ts/qcadgui_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>RCadToolBar</name>
    <message>
        <location filename="../src/gui/RCadToolBar.cpp" line="+139"/>
        <source>Vertical/Horizontal</source>
        <translation type="unfinished">Vertikální/horizontální</translation>
    </message>
</context>
<context>
    <name>RCadToolBarPanel</name>
    <message>
        <location filename="../src/gui/RCadToolBarPanel.cpp" line="+23"/>
        <location line="+63"/>
        <source>Back</source>
        <translation type="unfinished">Zpět</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+154"/>
        <source>Custom</source>
        <translation>Vlastní</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+211"/>
        <source>Grid</source>
        <translation>Mřížka</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>Konec</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>Objekt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>Kolmo</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>Tečně</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>Střed</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>Uprostřed</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>Průsečík</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>Reference</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Distance</source>
        <translation type="unfinished">Vzdálenost</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+188"/>
        <source>Invalid</source>
        <translation>Neplatné</translation>
    </message>
</context>
</TS>

==> qcad-3.32.4.4-3-x86_64.pkg.tar.zst: usr/lib/qcad/ts/qcadgui_cs.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="cs">
<context>
    <name>RCadToolBar</name>
    <message>
        <location filename="../src/gui/RCadToolBar.cpp" line="+139"/>
        <source>Vertical/Horizontal</source>
        <translation>Vertikální/horizontální</translation>
    </message>
</context>
<context>
    <name>RCadToolBarPanel</name>
    <message>
        <location filename="../src/gui/RCadToolBarPanel.cpp" line="+23"/>
        <location line="+63"/>
        <source>Back</source>
        <translation>Zpět</translation>
    </message>
</context>
<context>
    <name>RColorCombo</name>
    <message>
        <location filename="../src/gui/RColorCombo.cpp" line="+154"/>
        <source>Custom</source>
        <translation>Vlastní</translation>
    </message>
</context>
<context>
    <name>REventHandler</name>
    <message>
        <location filename="../src/gui/REventHandler.cpp" line="+211"/>
        <source>Grid</source>
        <translation>Mřížka</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>End</source>
        <translation>Konec</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>On Entity</source>
        <translation>Objekt</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Perpendicular</source>
        <translation>Kolmo</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Tangential</source>
        <translation>Tečně</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Center</source>
        <translation>Střed</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Middle</source>
        <translation>Uprostřed</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Intersection</source>
        <translation>Průsečík</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Reference</source>
        <translation>Reference</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Distance</source>
        <translation>Vzdálenost</translation>
    </message>
</context>
<context>
    <name>RMathLineEdit</name>
    <message>
        <location filename="../src/gui/RMathLineEdit.cpp" line="+188"/>
        <source>Invalid</source>
        <translation>Neplatné</translation>
    </message>
</context>
</TS>
